==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicPanelUI.h <==
// public class javax.swing.plaf.basic.BasicPanelUI

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 9f393451fe8ae81c javax_swing_plaf_ComponentUI
// @dep_class d7f8ed72eea34302 javax_swing_plaf_PanelUI
// @dep_class 2d7c79ec306a699e javax_swing_plaf_basic_BasicPanelUI

// header file dependencies
// @dep_header javax_swing_plaf_PanelUI

#include "javax/swing/plaf/PanelUI.h"

#ifndef _JC_javax_swing_plaf_basic_BasicPanelUI_H_
#define _JC_javax_swing_plaf_basic_BasicPanelUI_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_JComponent$object;
struct _jc_javax_swing_plaf_ComponentUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicPanelUI$sub_refs	_jc_javax_swing_plaf_basic_BasicPanelUI$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicPanelUI$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicPanelUI$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicPanelUI$refs	_jc_javax_swing_plaf_basic_BasicPanelUI$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicPanelUI$nonrefs	_jc_javax_swing_plaf_basic_BasicPanelUI$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicPanelUI$object	_jc_javax_swing_plaf_basic_BasicPanelUI$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicPanelUI$vmethods	_jc_javax_swing_plaf_basic_BasicPanelUI$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicPanelUI$vtable	_jc_javax_swing_plaf_basic_BasicPanelUI$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicPanelUI$vtype	_jc_javax_swing_plaf_basic_BasicPanelUI$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicPanelUI$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicPanelUI$object *);

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicPanelUI$method$installUI$ddb69f0251b0939f(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicPanelUI$object *, struct _jc_javax_swing_JComponent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicPanelUI$method_info$installUI$ddb69f0251b0939f;

// Static methods
extern struct _jc_javax_swing_plaf_ComponentUI$object *_jc_javax_swing_plaf_basic_BasicPanelUI$method$createUI$32e25151aaddad9d(_jc_env *, struct _jc_javax_swing_JComponent$object *);

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicPanelUI$vmethods {
	void	(*installUI$ddb69f0251b0939f)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicPanelUI$object *, struct _jc_javax_swing_JComponent$object *);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicPanelUI$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_ComponentUI$vmethods	javax_swing_plaf_ComponentUI;
	_jc_javax_swing_plaf_PanelUI$vmethods	javax_swing_plaf_PanelUI;
	_jc_javax_swing_plaf_basic_BasicPanelUI$vmethods	javax_swing_plaf_basic_BasicPanelUI;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicPanelUI$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicPanelUI$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicPanelUI$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicPanelUI$refs {
    _jc_javax_swing_plaf_basic_BasicPanelUI$sub_refs	javax_swing_plaf_basic_BasicPanelUI;
    _jc_javax_swing_plaf_PanelUI$sub_refs	javax_swing_plaf_PanelUI;
    _jc_javax_swing_plaf_ComponentUI$sub_refs	javax_swing_plaf_ComponentUI;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicPanelUI$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicPanelUI$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_ComponentUI$sub_nonrefs	javax_swing_plaf_ComponentUI;
    _jc_javax_swing_plaf_PanelUI$sub_nonrefs	javax_swing_plaf_PanelUI;
    _jc_javax_swing_plaf_basic_BasicPanelUI$sub_nonrefs	javax_swing_plaf_basic_BasicPanelUI;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicPanelUI$object {
	_jc_javax_swing_plaf_basic_BasicPanelUI$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicPanelUI$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicPanelUI$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicPanelUI$vtype _jc_javax_swing_plaf_basic_BasicPanelUI$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicPanelUI, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicPanelUI$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicPanelUI_H_ */

==> jc-1.4.5.tar.gz: javax/swing/plaf/basic/BasicPanelUI.h <==
// public class javax.swing.plaf.basic.BasicPanelUI

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 9f393451fe8ae81c javax_swing_plaf_ComponentUI
// @dep_class d7f8ed72eea34302 javax_swing_plaf_PanelUI
// @dep_class 2d7c79ec306a699e javax_swing_plaf_basic_BasicPanelUI

// header file dependencies
// @dep_header javax_swing_plaf_PanelUI

#include "javax/swing/plaf/PanelUI.h"

#ifndef _JC_javax_swing_plaf_basic_BasicPanelUI_H_
#define _JC_javax_swing_plaf_basic_BasicPanelUI_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_JComponent$object;
struct _jc_javax_swing_plaf_ComponentUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicPanelUI$sub_refs	_jc_javax_swing_plaf_basic_BasicPanelUI$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicPanelUI$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicPanelUI$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicPanelUI$refs	_jc_javax_swing_plaf_basic_BasicPanelUI$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicPanelUI$nonrefs	_jc_javax_swing_plaf_basic_BasicPanelUI$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicPanelUI$object	_jc_javax_swing_plaf_basic_BasicPanelUI$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicPanelUI$vmethods	_jc_javax_swing_plaf_basic_BasicPanelUI$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicPanelUI$vtable	_jc_javax_swing_plaf_basic_BasicPanelUI$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicPanelUI$vtype	_jc_javax_swing_plaf_basic_BasicPanelUI$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicPanelUI$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicPanelUI$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicPanelUI$method$installUI$ddb69f0251b0939f(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicPanelUI$object *, struct _jc_javax_swing_JComponent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicPanelUI$method_info$installUI$ddb69f0251b0939f;

// Static methods
extern struct _jc_javax_swing_plaf_ComponentUI$object *_jc_javax_swing_plaf_basic_BasicPanelUI$method$createUI$32e25151aaddad9d(_jc_env *, struct _jc_javax_swing_JComponent$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicPanelUI$vmethods {
	void	(*installUI$ddb69f0251b0939f)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicPanelUI$object *, struct _jc_javax_swing_JComponent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicPanelUI$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_ComponentUI$vmethods	javax_swing_plaf_ComponentUI;
	_jc_javax_swing_plaf_PanelUI$vmethods	javax_swing_plaf_PanelUI;
	_jc_javax_swing_plaf_basic_BasicPanelUI$vmethods	javax_swing_plaf_basic_BasicPanelUI;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicPanelUI$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicPanelUI$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicPanelUI$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicPanelUI$refs {
    _jc_javax_swing_plaf_basic_BasicPanelUI$sub_refs	javax_swing_plaf_basic_BasicPanelUI;
    _jc_javax_swing_plaf_PanelUI$sub_refs	javax_swing_plaf_PanelUI;
    _jc_javax_swing_plaf_ComponentUI$sub_refs	javax_swing_plaf_ComponentUI;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicPanelUI$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicPanelUI$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_ComponentUI$sub_nonrefs	javax_swing_plaf_ComponentUI;
    _jc_javax_swing_plaf_PanelUI$sub_nonrefs	javax_swing_plaf_PanelUI;
    _jc_javax_swing_plaf_basic_BasicPanelUI$sub_nonrefs	javax_swing_plaf_basic_BasicPanelUI;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicPanelUI$object {
	_jc_javax_swing_plaf_basic_BasicPanelUI$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicPanelUI$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicPanelUI$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicPanelUI$vtype _jc_javax_swing_plaf_basic_BasicPanelUI$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicPanelUI, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicPanelUI$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicPanelUI_H_ */
